v1

package
v0.0.56 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

const OperationOtherGetImageCaptcha = "/api.other.v1.Other/GetImageCaptcha"
const (
	Other_GetImageCaptcha_FullMethodName = "/api.other.v1.Other/GetImageCaptcha"
)

Variables

var File_other_v1_common_proto protoreflect.FileDescriptor
var File_other_v1_other_proto protoreflect.FileDescriptor
var Other_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "api.other.v1.Other",
	HandlerType: (*OtherServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetImageCaptcha",
			Handler:    _Other_GetImageCaptcha_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "other/v1/other.proto",
}

Other_ServiceDesc is the grpc.ServiceDesc for Other service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOtherHTTPServer

func RegisterOtherHTTPServer(s *http.Server, srv OtherHTTPServer)

func RegisterOtherServer

func RegisterOtherServer(s grpc.ServiceRegistrar, srv OtherServer)

Types

type Empty

type Empty struct {
	// contains filtered or unexported fields
}

空消息

func (*Empty) Descriptor deprecated

func (*Empty) Descriptor() ([]byte, []int)

Deprecated: Use Empty.ProtoReflect.Descriptor instead.

func (*Empty) ProtoMessage

func (*Empty) ProtoMessage()

func (*Empty) ProtoReflect

func (x *Empty) ProtoReflect() protoreflect.Message

func (*Empty) Reset

func (x *Empty) Reset()

func (*Empty) String

func (x *Empty) String() string

type OtherClient

type OtherClient interface {
	// 获取图形验证码
	GetImageCaptcha(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*Reply, error)
}

OtherClient is the client API for Other service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewOtherClient

func NewOtherClient(cc grpc.ClientConnInterface) OtherClient

type OtherHTTPClient

type OtherHTTPClient interface {
	GetImageCaptcha(ctx context.Context, req *Empty, opts ...http.CallOption) (rsp *Reply, err error)
}

func NewOtherHTTPClient

func NewOtherHTTPClient(client *http.Client) OtherHTTPClient

type OtherHTTPClientImpl

type OtherHTTPClientImpl struct {
	// contains filtered or unexported fields
}

func (*OtherHTTPClientImpl) GetImageCaptcha

func (c *OtherHTTPClientImpl) GetImageCaptcha(ctx context.Context, in *Empty, opts ...http.CallOption) (*Reply, error)

type OtherHTTPServer

type OtherHTTPServer interface {
	// GetImageCaptcha 获取图形验证码
	GetImageCaptcha(context.Context, *Empty) (*Reply, error)
}

type OtherServer

type OtherServer interface {
	// 获取图形验证码
	GetImageCaptcha(context.Context, *Empty) (*Reply, error)
	// contains filtered or unexported methods
}

OtherServer is the server API for Other service. All implementations must embed UnimplementedOtherServer for forward compatibility.

type Reply

type Reply struct {
	StatusCode int32  `protobuf:"varint,1,opt,name=status_code,json=statusCode,proto3" json:"status_code,omitempty"` // 状态码
	Message    string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`                          // 提示信息
	Data       string `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`                                // json字符串
	// contains filtered or unexported fields
}

func (*Reply) Descriptor deprecated

func (*Reply) Descriptor() ([]byte, []int)

Deprecated: Use Reply.ProtoReflect.Descriptor instead.

func (*Reply) GetData

func (x *Reply) GetData() string

func (*Reply) GetMessage

func (x *Reply) GetMessage() string

func (*Reply) GetStatusCode

func (x *Reply) GetStatusCode() int32

func (*Reply) ProtoMessage

func (*Reply) ProtoMessage()

func (*Reply) ProtoReflect

func (x *Reply) ProtoReflect() protoreflect.Message

func (*Reply) Reset

func (x *Reply) Reset()

func (*Reply) String

func (x *Reply) String() string

type UnimplementedOtherServer

type UnimplementedOtherServer struct{}

UnimplementedOtherServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOtherServer) GetImageCaptcha

func (UnimplementedOtherServer) GetImageCaptcha(context.Context, *Empty) (*Reply, error)

type UnsafeOtherServer

type UnsafeOtherServer interface {
	// contains filtered or unexported methods
}

UnsafeOtherServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OtherServer will result in compilation errors.

Source Files

  • common.pb.go
  • other.pb.go
  • other_grpc.pb.go
  • other_http.pb.go

Jump to